from time import time
from setuptools import setup, find_packages
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
setup(
    name='abstract_hugpy',
    version='0.0.1',
    author='putkoff',
    author_email='partners@abstractendeavors.com',
    description='The `abstract_hugpy` module is designed to facilitate hugging face modules',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/AbstractEndeavors/abstract_hugpy',
    package_dir={"": "src"},
    packages=find_packages(where="src"),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    install_requires=[
        "huggingface_hub>=0.20",
        "numpy",
        "regex",
    ],

    extras_require={
        "ml": [
            "torch>=2.2",
            "transformers>=4.40",
            "sentence-transformers>=2.6",
            "keybert>=0.8",
            "accelerate>=0.30",
        ],

        "ocr": [
            "paddleocr",
            "opencv-python",
            "pdf2image",
        ],

        "video": [
            "moviepy",
            "openai-whisper",
        ],

        "nlp": [
            "spacy>=3.7",
        ],

        "full": [
            "torch>=2.2",
            "transformers>=4.40",
            "sentence-transformers>=2.6",
            "keybert>=0.8",
            "accelerate>=0.30",
            "spacy>=3.7",
            "moviepy",
            "openai-whisper",
            "paddleocr",
            "opencv-python",
            "pdf2image",
            "abstract_security",
            "bs4",
            "abstract_ai"
        ],
    },

    python_requires=">=3.10",
)
